(utilities)=

# Utilities

In this section you find the reference documentation of the modules contained in
the util module.

- {ref}`general <utilsgeneral>`
- {ref}`names <utilsnames>`

(utilsgeneral)=

## general

```{eval-rst}
.. automodule:: utils.general
   :members:

```

(utilsgeometry)=

## geometry

```{eval-rst}
.. automodule:: utils.geometry
   :members:
```

(utilsnames)=

## names

```{eval-rst}
.. automodule:: utils.names
   :members:
```

## value_conversion

```{eval-rst}
.. automodule:: utils.value_conversion
   :members:
```

## constants

```{eval-rst}
.. automodule:: constants
   :members:
```
